@@ -17,8 +17,6 @@ module MiniMagick
           cheap_info(value)
         when "colorspace"
           colorspace
-        when "mime_type"
-          mime_type
         when "resolution"
           resolution(*args)
         when "signature"
@@ -27,8 +25,6 @@ module MiniMagick
           raw_exif(value)
         when "exif"
           exif
-        when "details"
-          details
         when "data"
           data
         else
@@ -42,7 +38,7 @@ module MiniMagick
 
       def cheap_info(value)
         @info.fetch(value) do
-          format, width, height, size = self["%m %w %h %b"].split(" ")
+          format, width, height, size = parse_warnings(self["%m %w %h %b"]).split(" ")
 
           path = @path
           path = path.match(/\[\d+\]$/).pre_match if path =~ /\[\d+\]$/
@@ -62,12 +58,18 @@ module MiniMagick
         raise MiniMagick::Invalid, "image data can't be read"
       end
 
-      def colorspace
-        @info["colorspace"] ||= self["%r"]
+      def parse_warnings(raw_info)
+        return raw_info unless raw_info.split("\n").size > 1
+
+        raw_info.split("\n").each do |line|
+          # must match "%m %w %h %b"
+          return line if line.match?(/^[A-Z]+ \d+ \d+ \d+(|\.\d+)([KMGTPEZY]{0,1})B$/)
+        end
+        raise TypeError
       end
 
-      def mime_type
-        "image/#{self["format"].downcase}"
+      def colorspace
+        @info["colorspace"] ||= self["%r"]
       end
 
       def resolution(unit = nil)
@@ -90,20 +92,12 @@ module MiniMagick
           output.each_line do |line|
             line = line.chomp("\n")
 
-            case MiniMagick.cli
-            when :imagemagick, :imagemagick7
-              if match = line.match(/^exif:/)
-                key, value = match.post_match.split("=", 2)
-                value = decode_comma_separated_ascii_characters(value) if ASCII_ENCODED_EXIF_KEYS.include?(key)
-                hash[key] = value
-              else
-                hash[hash.keys.last] << "\n#{line}"
-              end
-            when :graphicsmagick
-              next if line == "unknown"
-              key, value = line.split("=", 2)
-              value.gsub!("\\012", "\n") # convert "\012" characters to newlines
+            if match = line.match(/^exif:/)
+              key, value = match.post_match.split("=", 2)
+              value = decode_comma_separated_ascii_characters(value) if ASCII_ENCODED_EXIF_KEYS.include?(key)
               hash[key] = value
+            else
+              hash[hash.keys.last] << "\n#{line}"
             end
           end
 
@@ -119,44 +113,9 @@ module MiniMagick
         @info["signature"] ||= self["%#"]
       end
 
-      def details
-        warn "[MiniMagick] MiniMagick::Image#details has been deprecated, as it was causing too many parsing errors. You should use MiniMagick::Image#data instead, which differs in a way that the keys are in camelcase." if MiniMagick.imagemagick? || MiniMagick.imagemagick7?
-
-        @info["details"] ||= (
-          details_string = identify(&:verbose)
-          key_stack = []
-          details_string.lines.to_a[1..-1].each_with_object({}) do |line, details_hash|
-            next if !line.valid_encoding? || line.strip.length.zero?
-
-            level = line[/^\s*/].length / 2 - 1
-            if level >= 0
-              key_stack.pop until key_stack.size <= level
-            else
-              # Some metadata, such as SVG clipping paths, will be saved without
-              # indentation, resulting in a level of -1
-              last_key = details_hash.keys.last
-              details_hash[last_key] = '' if details_hash[last_key].empty?
-              details_hash[last_key] << line
-              next
-            end
-
-            key, _, value = line.partition(/:[\s]/).map(&:strip)
-            hash = key_stack.inject(details_hash) { |_hash, _key| _hash.fetch(_key) }
-            if value.empty?
-              hash[key] = {}
-              key_stack.push key
-            else
-              hash[key] = value
-            end
-          end
-        )
-      end
-
       def data
-        raise Error, "MiniMagick::Image#data isn't supported on GraphicsMagick. Use MiniMagick::Image#details instead." if MiniMagick.graphicsmagick?
-
         @info["data"] ||= (
-          json = MiniMagick::Tool::Convert.new do |convert|
+          json = MiniMagick.convert do |convert|
             convert << path
             convert << "json:"
           end
@@ -168,7 +127,7 @@ module MiniMagick
       end
 
       def identify
-        MiniMagick::Tool::Identify.new do |builder|
+        MiniMagick.identify do |builder|
           yield builder if block_given?
           builder << path
         end
