@@ -3,11 +3,15 @@ require "mini_magick"
 
 require_relative "support/helpers"
 
-MiniMagick.cli = :graphicsmagick if ENV["GM"]
-
 RSpec.configure do |config|
   config.disable_monkey_patching!
   config.formatter = "documentation"
   config.color = true
   config.fail_fast = true unless ENV["CI"]
+
+  config.mock_with :rspec do |mocks|
+    # Prevents you from mocking or stubbing a method that does not exist on
+    # a real object.
+    mocks.verify_partial_doubles = true
+  end
 end
